Date: 07 12, 2001 1:31:09 PM

Using Page Mode

Page Mode allows you to automatically browse multiple windows simultaneously. For example, if you've run the analyzer on a folder, you can then open a window for the input file and output file, then browse among all the input-output pairs using the left and right arrows on the Workspace Toolbar. If a parse tree view is open, you can also browse the parse tree for each pass of a single text analysis.

To browse between multiple files in an input folder:

1. Select the Toggle Page Mode button on the Debug Toolbar. This activates the yellow Previous Text and Next Text buttons.

2. Open a file from an input directory.

3. Select the yellow Next Text button to view the next file in the input directory. Select the Previous Text button to view the last file.

To update parse tree displays for passes in the analyzer sequence:

1. Select the Toggle Generate Logs button and run the analyzer.

2. Click on the View Parse Tree button to display the parse tree.

3. Select the Toggle Page Mode button.

4. In the Ana Tab, click on a pass to update the parse tree display in the Workspace.